# IoT Kernel

The `IoT Kernel` facilitates connecting to and programming microcontrollers running MicroPython and derivatives from Jupyter.

To install the kernel from PyPI:

```
pip install iot-kernel
python -m iot_kernel.install
```
